OC.L10N.register(
    "mail",
    {
    "Mail" : "ფოსტა",
    "Loading accounts" : "ანგარიშების ჩატვირთვა",
    "Error while loading the accounts." : "ანგარიშების ჩატვირთვისას წარმოიქმნა შეცდომა.",
    "Error while loading the selected account." : "არჩეული ანგარიშების ჩატვირთვისას წარმოიშვა შეცდომა.",
    "Can not load this folder." : "ამ დირექტორიის ჩატვირთვა ვერ მოხერხდა.",
    "Searching for {query}" : "ვეძებთ {query}-ის",
    "Error while deleting message." : "წერილების გაუქმებისას წარმოიშვა შეცდომა",
    "Forwarded message" : "წერილის გადამისამართება",
    "Choose a folder to store the attachment in" : "გთხოვთ აირჩიოთ დირექტორია, სადაც მოთავსდება დანართი",
    "Attachments saved to Files." : "დანართები შენახულია ფაილებში.",
    "Attachment saved to Files." : "დანართი შენახულია ფაილებში.",
    "Error while saving attachments to Files." : "დანართების ფაილებში შენახვისას წარმოიშვა შეცდომა.",
    "Error while saving attachment to Files." : "დანართის ფაილებში შენახვისას წარმოიშვა შეცდომა.",
    "Message flag could not be set." : "წერილის დროშა ვერ დაყენდა.",
    "Could not move message." : "წერილის გადატანა ვერ მოხერხდა.",
    "Invalid account" : "არასწორი ანგარიში",
    "Invalid folder" : "არასწორი დირექტორია",
    "Error while creating the account: " : "ანგარიშის შექმნისას წარმოიშვა შეცდომა:",
    "Unknown error" : "უცნობი შეცდომა",
    "Error while updating the account: " : "ანგარიშის განახლებისას წარმოიშვა შეცდომა:",
    "All inboxes" : "ყველა ინბოქსი",
    "you" : "თქვენ",
    "Send message to {email}" : "გაუგზავნეთ წერილი {email}-ს",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ვერ ჩაიტვირთა",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}-ის ჩატვირთვისას მოხდა შეცდომა",
    "Could not load your message" : "თქვენი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the desired message" : "სასურველი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the message" : "წერილის ჩატვირთვა ვერ მოხერხდა",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ახალი წერილი\n{from}-ისგან"],
    "Nextcloud Mail" : "Nextcloud ფოსტა",
    "Save" : "შენახვა",
    "Saved" : "შენახულია",
    "Show all folders" : "ყველა დირექტორიის ჩვენება",
    "Collapse folders" : "დირექტორიების კოლაფსი",
    "Error while deleting account." : "ანგარიშის გაუქმებისას წარმოიშვა შეცდომა.",
    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
    "An error occurred while uploading {fname}" : "{fname}-ის ატვირთვისას წარმოიშვა შეცდომა",
    "Reply" : "პასუხი",
    "Send" : "გაგზავნა",
    "Sending …" : "იგზავნება …",
    "Message sent!" : "წერილი გაგზავნილია!",
    "Server error" : "სერვერის შეცდომა",
    "An unknown error occurred" : "გამოჩნდა ამოუცნობი შეცდომა",
    "Opening HTML drafts is not supported yet." : "HTML მონახაზის გახსნა ჯერ მხარდაჭერილი არაა.",
    "No writable calendars found" : "ჩაწერადი კალენდრები ვერ იქნა ნაპოვნი",
    "Error while importing the calendar event" : "კალენდრის მოვლენის იმპორტირებისას წარმოიშვა შეცდომა",
    "Error while downloading calendar event" : "კალენდრის მოვლენის ჩამოტვირთვისას წარმოიშვა შეცდომა",
    "& others" : "და სხვები",
    "Error while loading messages." : "წერილების ჩატვირთვისას წარმოიშვა შეცდომა.",
    "Error while refreshing messages." : "წერილების განახლებისას წარმოიშვა შეცდომა.",
    "Setting up your account" : "ანგარიშის დაყენება",
    "Inbox" : "ინბოქსი",
    "Sent" : "გაგზავნილი",
    "Drafts" : "მონახაზები",
    "Archive" : "არქივი",
    "Trash" : "ნაგავი",
    "Junk" : "უსარგებლო",
    "All" : "ყველა",
    "Favorites" : "რჩეული",
    "Auto detect failed. Please use manual mode." : "ავტო-აღმოჩენა ვერ მოხერხდა. გთხოვთ სცადოთ ხელით.",
    "Updating account failed: " : "ანგარიშის განახლება ვერ მოხერხდა:",
    "Creating account failed: " : "ანგარიშების შექმნა ვერ მოხერხდა:",
    "Delete permanently" : "სამუდამოდ წაშლა",
    "Error loading message" : "წერილის ჩატვირთვისას წარმოიშვა შეცდომა",
    "Settings" : "პარამეტრები",
    "Forwarding to %s" : "გადაგზავნილია %s-ზე",
    "Click here if you are not automatically redirected within the next few seconds." : "იმ შემთხვევაში, თუ რამდენიმე წამის განმავლობაში არ მოხდება ავტომატური გადამისამართება დააწკაპუნეთ აქ.",
    "Redirect" : "გადამისამართება",
    "The link leads to %s" : "ბმულს მიყევხართ %s-ისკენ",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "თუ არ გსურთ ესტუმროთ იმ გვერდს, შეგიძლიათ დაუბრუნდეთ <a href=\"%s\">ფოსტას</a>.",
    "Continue to %s" : "%s-ისკენ გაგრძელება",
    "Delete account" : "ანგარიშის გაუქმება",
    "Try again" : "სცადეთ ახლიდან",
    "New message" : "ახალი წერილი",
    "Account Settings" : "ანგარიშის პარამეტრები",
    "Aliases" : "სხვანაირი სახელი",
    "Mail address" : "ფოსტის მისამართი",
    "Display Name" : "დისპლეი სახელი",
    "Account" : "ანგარიში",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Speed up your Mail experience with these quick shortcuts." : "მოიხმარეთ ეს კომბინაციები ფოსტასთან უფრო სწრაფად სამუშაოდ.",
    "Compose new message" : "ახალი წერილის შედგენა",
    "Newer message" : "უფრო ახალი წერილი",
    "Older message" : "ძველი წერილი",
    "Toggle star" : "ვარსკლავის გადართვა",
    "Toggle unread" : "წაუკითხავის გადართვა",
    "Delete" : "გაუქმება",
    "Search" : "ძიება",
    "Refresh" : "განახლება",
    "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
    "Name" : "სახელი",
    "Mail Address" : "ფოსტის მისამართი",
    "Password" : "პაროლი",
    "Manual configuration" : "კონფიგურირება ხელით",
    "IMAP Host" : "IMAP ჰოსტი",
    "IMAP security" : "IMAP უსაფრთხოება",
    "None" : "არც ერთი",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP პორტი",
    "IMAP User" : "IMAP მომხმარებელი",
    "IMAP Password" : "IMAP პაროლი",
    "SMTP Host" : "SMTP ჰოსტი",
    "SMTP security" : "SMTP უსაფრთხოება",
    "SMTP Port" : "SMTP პორტი",
    "SMTP User" : "SMTP მომხმარებელი",
    "SMTP Password" : "SMTP პაროლი",
    "Connect" : "დაკავშირება",
    "from" : "ვისგან",
    "to" : "ვის",
    "cc" : "კკ",
    "bcc" : "ბკკ",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "შენიშნეთ რომ წერილი მიღებულია \"დაუბრუნებელი\" მისამართიდან, ასე რომ თქვენი პასუხი სავარაუდოდ არ იქნება წაკითხული.",
    "Subject" : "სათაური",
    "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
    "Add mail account" : "საფოსტო ანგარიშის დამატება",
    "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
    "No search results for" : "ძიების შედეგები არაა",
    "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
    "Show images from this sender" : "ამ გამომგზავნელისგან სურათების ჩვენება",
    "Forward" : "გადამისამართება",
    "No messages in this folder!" : "ამ დირექტორიაში წერილები არაა",
    "Upload attachment" : "დანართის ატვირთვა",
    "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
    "Import into calendar" : "იმპორტი კალენდარში",
    "Download attachment" : "დანართის გადმოწერა",
    "Save to Files" : "შენახვა ფაილებში"
},
"nplurals=1; plural=0;");
